@@ -8,7 +8,7 @@ typedef struct semanage_bool_key record_key_t;
 
 struct dbase_file;
 typedef struct dbase_file dbase_t;
-#define DBASE_DEFINED 
+#define DBASE_DEFINED
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -20,12 +20,11 @@ typedef struct dbase_file dbase_t;
 #include "parse_utils.h"
 #include "debug.h"
 
-static int bool_print(
-	semanage_handle_t* handle,
-	semanage_bool_t* boolean, 
-	FILE* str) {
+static int bool_print(semanage_handle_t * handle,
+		      const semanage_bool_t * boolean, FILE * str)
+{
 
-	const char* name = semanage_bool_get_name(boolean);
+	const char *name = semanage_bool_get_name(boolean);
 	int value = semanage_bool_get_value(boolean);
 
 	if (fprintf(str, "%s=%d\n", name, value) < 0) {
@@ -36,13 +35,12 @@ static int bool_print(
 	return STATUS_SUCCESS;
 }
 
-static int bool_parse(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	semanage_bool_t* boolean) {
-	
+static int bool_parse(semanage_handle_t * handle,
+		      parse_info_t * info, semanage_bool_t * boolean)
+{
+
 	int value = 0;
-	char* str = NULL;
+	char *str = NULL;
 
 	if (parse_skip_space(handle, info) < 0)
 		goto err;
@@ -50,10 +48,10 @@ static int bool_parse(
 		goto last;
 
 	/* Extract name */
-	if (parse_fetch_string(handle, info, &str, '=') < 0)
+	if (parse_fetch_string(handle, info, &str, '=', 0) < 0)
 		goto err;
-	
-	if (semanage_bool_set_name(handle, boolean, str) < 0) 
+
+	if (semanage_bool_set_name(handle, boolean, str) < 0)
 		goto err;
 	free(str);
 	str = NULL;
@@ -67,7 +65,7 @@ static int bool_parse(
 	/* Extract value */
 	if (parse_skip_space(handle, info) < 0)
 		goto err;
-	if (parse_optional_str(info, "true") != STATUS_NODATA) 
+	if (parse_optional_str(info, "true") != STATUS_NODATA)
 		value = 1;
 	else if (parse_optional_str(info, "TRUE") != STATUS_NODATA)
 		value = 1;
@@ -77,11 +75,11 @@ static int bool_parse(
 		value = 0;
 	else if (parse_fetch_int(handle, info, &value, ' ') < 0)
 		goto err;
-	
+
 	if (value != 0 && value != 1) {
 		ERR(handle, "invalid boolean value for \"%s\": %u "
-			"(%s: %u)\n%s", semanage_bool_get_name(boolean),
-			value, info->filename, info->lineno, info->orig_line);
+		    "(%s: %u)\n%s", semanage_bool_get_name(boolean),
+		    value, info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 	semanage_bool_set_value(boolean, value);
@@ -91,11 +89,11 @@ static int bool_parse(
 
 	return STATUS_SUCCESS;
 
-	last:
+      last:
 	parse_dispose_line(info);
 	return STATUS_NODATA;
 
-        err:
+      err:
 	ERR(handle, "could not parse boolean record");
 	free(str);
 	parse_dispose_line(info);
@@ -103,30 +101,30 @@ static int bool_parse(
 }
 
 /* BOOL RECORD: FILE extension: method table */
-record_file_table_t SEMANAGE_BOOL_FILE_RTABLE = {
-	.parse       = bool_parse,
-	.print       = bool_print,
+static const record_file_table_t SEMANAGE_BOOL_FILE_RTABLE = {
+	.parse = bool_parse,
+	.print = bool_print,
 };
 
-int bool_file_dbase_init(
-	semanage_handle_t* handle, 
-	const char* fname,
-	dbase_config_t* dconfig) {
-	
-	if (dbase_file_init(
-		handle, 
-		fname,
-		&SEMANAGE_BOOL_RTABLE,
-		&SEMANAGE_BOOL_FILE_RTABLE, 
-		&dconfig->dbase) < 0)
+int bool_file_dbase_init(semanage_handle_t * handle,
+			 const char *path_ro,
+			 const char *path_rw,
+			 dbase_config_t * dconfig)
+{
+
+	if (dbase_file_init(handle,
+			    path_ro,
+			    path_rw,
+			    &SEMANAGE_BOOL_RTABLE,
+			    &SEMANAGE_BOOL_FILE_RTABLE, &dconfig->dbase) < 0)
 		return STATUS_ERR;
 
 	dconfig->dtable = &SEMANAGE_FILE_DTABLE;
 	return STATUS_SUCCESS;
 }
 
-void bool_file_dbase_release(
-	dbase_config_t* dconfig) {
+void bool_file_dbase_release(dbase_config_t * dconfig)
+{
 
 	dbase_file_release(dconfig->dbase);
 }
